@@ -81,7 +81,7 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 			$this->sized_dynamic_styles( $css, $nav_attributes, $unique_id, $size );
 		}
 		$css->set_media_state( 'desktop' );
-
+	
 		// No added specificty needed for these variables.
 		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id );
 		$css->render_measure_output( $nav_attributes, 'marginLink', '--kb-nav-top-link-margin', ['unit_key' => 'marginLinkUnit']);
@@ -115,13 +115,13 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 		$css->render_measure_output( $nav_attributes, 'padding', '--kb-nav-padding', ['unit_key' => 'paddingUnit']);
 
 		//nav item (top level only)
-		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id . ' > .navigation > .menu-container > .menu > .wp-block-kadence-navigation-link > .kb-link-wrap' );
+		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id . ' > .navigation > .menu-container > .menu > .wp-block-kadence-navigation-link > .kb-link-wrap > .kb-nav-link-content' );
 		$css->render_typography( $nav_attributes );
 
 		//dropdown links (only this nav's dropdowns, exclude embedded navigations in mega menus, etc)
 		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id . ' .sub-menu > .wp-block-kadence-navigation-link > .kb-link-wrap > .kb-nav-link-content' );
 		$css->render_typography( $nav_attributes, 'dropdownTypography' );
-
+		
 		//nav item (top level only) descriptions
 		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id . ' .menu-container > .menu > .wp-block-kadence-navigation-link > .kb-link-wrap .kb-nav-label-description' );
 		$css->render_typography( $nav_attributes, 'descriptionTypography' );
@@ -150,7 +150,7 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id );
 		$css->add_property( '--kb-nav-top-link-color-active-ancestor', $css->render_color( $sized_attributes['linkColorActive']), $sized_attributes['parentActive'] );
 		$css->add_property( '--kb-nav-top-link-background-active-ancestor', $css->render_color( $sized_attributes['backgroundActive']), $sized_attributes['parentActive'] );
-		$css->add_property( '--kb-nav-dropdown-link-color', $css->render_color( $sized_attributes['linkColorDropdown'] ));
+		$css->add_property( '--kb-nav-dropdown-link-color', $css->render_color( $sized_attributes['linkColorDropdown'] ));		
 		$css->add_property( '--kb-nav-dropdown-link-color-hover', $css->render_color( $sized_attributes['linkColorDropdownHover'] ) );
 		$css->add_property( '--kb-nav-dropdown-link-color-active', $css->render_color( $sized_attributes['linkColorDropdownActive']) );
 		$css->add_property( '--kb-nav-dropdown-link-color-active-ancestor', $css->render_color( $sized_attributes['linkColorDropdownActive']), $sized_attributes['parentActive'] );
@@ -163,31 +163,31 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 		$css->add_property( '--kb-nav-dropdown-border-right', $css->render_border( $sized_attributes['dropdownBorder'], 'right' ) );
 		$css->add_property( '--kb-nav-dropdown-link-padding-top', $css->render_size( $sized_attributes['dropdownVerticalSpacing'], $attributes['dropdownVerticalSpacingUnit'] ), $sized_attributes['dropdownVerticalSpacing'] );
 		$css->add_property( '--kb-nav-dropdown-link-padding-bottom', $css->render_size( $sized_attributes['dropdownVerticalSpacing'], $attributes['dropdownVerticalSpacingUnit'] ), $sized_attributes['dropdownVerticalSpacing'] );
-		$css->render_measure_range(
-			$sized_attributes,
-			( 'Desktop' === $size ? 'dropdownBorderRadius' : 'dropdownBorderRadius' . $size ),
-			'--kb-nav-dropdown-border-radius',
-			'',
+		$css->render_measure_range( 
+			$sized_attributes, 
+			( 'Desktop' === $size ? 'dropdownBorderRadius' : 'dropdownBorderRadius' . $size ), 
+			'--kb-nav-dropdown-border-radius', 
+			'', 
 			[
-				'unit_key' => 'dropdownBorderRadiusUnit',
+				'unit_key' => 'dropdownBorderRadiusUnit', 
 				'first_prop' => '--kb-nav-dropdown-border-top-left-radius',
 				'second_prop' => '--kb-nav-dropdown-border-top-right-radius',
 				'third_prop' => '--kb-nav-dropdown-border-bottom-right-radius',
-				'fourth_prop' => '--kb-nav-dropdown-border-bottom-left-radius'
+				'fourth_prop' => '--kb-nav-dropdown-border-bottom-left-radius' 
 			]
 		);
 		$css->render_measure_range( $sized_attributes, ( 'Desktop' === $size ? 'dropdownBorderRadius' : 'dropdownBorderRadius' . $size ), '--kb-nav-dropdown-border-radius', '', ['unit_key' => 'dropdownBorderRadiusUnit']);
-		$css->add_property( '--kb-nav-top-link-description-color', $css->render_color( $sized_attributes['descriptionColor'] ));
+		$css->add_property( '--kb-nav-top-link-description-color', $css->render_color( $sized_attributes['descriptionColor'] ));		
 		$css->add_property( '--kb-nav-top-link-description-color-hover', $css->render_color( $sized_attributes['descriptionColorHover'] ) );
 		$css->add_property( '--kb-nav-top-link-description-color-active', $css->render_color( $sized_attributes['descriptionColorActive']) );
 		$css->add_property( '--kb-nav-top-link-description-color-active-ancestor', $css->render_color( $sized_attributes['descriptionColorActive']), $sized_attributes['parentActive'] );
 		$css->add_property( '--kb-nav-top-link-description-padding-top', $css->render_size( $sized_attributes['descriptionSpacing'], $sized_attributes['descriptionSpacingUnit'] ?? 'px' ) );
-		$css->add_property( '--kb-nav-dropdown-link-description-color', $css->render_color( $sized_attributes['dropdownDescriptionColor'] ));
+		$css->add_property( '--kb-nav-dropdown-link-description-color', $css->render_color( $sized_attributes['dropdownDescriptionColor'] ));		
 		$css->add_property( '--kb-nav-dropdown-link-description-color-hover', $css->render_color( $sized_attributes['dropdownDescriptionColorHover'] ) );
 		$css->add_property( '--kb-nav-dropdown-link-description-color-active', $css->render_color( $sized_attributes['dropdownDescriptionColorActive']) );
 		$css->add_property( '--kb-nav-dropdown-link-description-color-active-ancestor', $css->render_color( $sized_attributes['dropdownDescriptionColorActive']), $sized_attributes['parentActive'] );
 		$css->add_property( '--kb-nav-dropdown-link-description-padding-top', $css->render_size( $sized_attributes['dropdownDescriptionSpacing'], $sized_attributes['dropdownDescriptionSpacingUnit'] ?? 'px' ) );
-
+		
 		//additional dynamic logic, but still lands in a slot in the static stylesheet
 		if ( isset( $navigation_vertical_spacing ) && is_numeric( $navigation_vertical_spacing ) ) {
 			$css->add_property( '--kb-nav-row-gap', $css->render_size( $navigation_vertical_spacing, $attributes['spacingUnit'] ) );
@@ -226,22 +226,6 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 			$css->add_property( '--kb-nav-top-not-last-link-border-right', 'var(--kb-nav-link-border-right)' );
 		}
 
-		//link, description, and media alignment
-		if ($sized_attributes['linkHorizontalAlignment']) {
-			$css->add_property('--kb-nav-top-link-align', $sized_attributes['linkHorizontalAlignment']);
-			$link_flex_align = $sized_attributes['linkHorizontalAlignment'] == 'right' ? 'end' : ( $sized_attributes['linkHorizontalAlignment'] == 'center' ? 'center' : 'start' );
-			$css->add_property('--kb-nav-top-link-flex-justify', $link_flex_align);
-			$css->add_property('--kb-nav-top-link-media-container-align-self', $link_flex_align);
-		}
-
-		//dropdown link, description, and media alignment
-		if ($sized_attributes['dropdownLinkHorizontalAlignment']) {
-			$css->add_property('--kb-nav-dropdown-link-align', $sized_attributes['dropdownLinkHorizontalAlignment']);
-			$link_flex_align = $sized_attributes['dropdownLinkHorizontalAlignment'] == 'right' ? 'end' : ( $sized_attributes['dropdownLinkHorizontalAlignment'] == 'center' ? 'center' : 'start' );
-			$css->add_property('--kb-nav-dropdown-link-flex-justify', $link_flex_align);
-			$css->add_property('--kb-nav-dropdown-link-media-container-align-self', $link_flex_align);
-		}
-
 		if ( str_contains( $sized_attributes['style'], 'fullheight' ) ) {
 			$css->add_property( '--kb-nav-height', '100%' );
 		}
@@ -291,7 +275,7 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 
 		//not last submenu items and mega menu nav links
 		$css->set_selector( '.wp-block-kadence-navigation' . $unique_id . ' .sub-menu > .menu-item:not(:last-of-type), .wp-block-kadence-navigation' . $unique_id . ' .sub-menu.mega-menu > .menu-item > .kb-link-wrap > .kb-nav-link-content' );
-		$css->add_property( '--kb-nav-menu-item-border-bottom', $css->render_border( $sized_attributes['dropdownDivider'], 'bottom' ) );
+		$css->add_property( '--kb-nav-menu-item-border-bottom', $css->render_border( $sized_attributes['dropdownDivider'], 'bottom' ) );		
 	}
 
 	/**
@@ -408,19 +392,13 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 
 		$name = ! empty( $attributes['name'] ) ? $attributes['name'] : '';
 
-		$wrapper_attribute_items = array(
-			'class'      => implode( ' ', $wrapper_classes ),
-			'aria-label' => $name,
-			'data-scroll-spy' => $nav_attributes['enableScrollSpy'],
+		$wrapper_attributes = get_block_wrapper_attributes(
+			array(
+				'class'      => implode( ' ', $wrapper_classes ),
+				'aria-label' => $name,
+			)
 		);
 
-		if ( $nav_attributes['enableScrollSpy'] ) {
-			$wrapper_attribute_items['data-scroll-spy-offset'] = isset( $nav_attributes['scrollSpyOffsetManual'] ) && $nav_attributes['scrollSpyOffsetManual'] ? $nav_attributes['scrollSpyOffset'] : false;
-			$wrapper_attribute_items['data-scroll-spy-id'] = uniqid();
-		}
-
-		$wrapper_attributes = get_block_wrapper_attributes( $wrapper_attribute_items );
-
 		// Navigation Attributes.
 		$navigation_classes = array();
 
@@ -460,14 +438,6 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 			)
 		);
 
-		if ( $nav_attributes['enableScrollSpy'] ) {
-			wp_enqueue_script( 'kadence-blocks-gumshoe', KADENCE_BLOCKS_URL . 'includes/assets/js/gumshoe.min.js', array(), KADENCE_BLOCKS_VERSION, true );
-			//need to load this script with the gumshoe dependency if scrollspy is enabled
-			wp_dequeue_script( 'kadence-blocks-' . $this->block_name );
-			wp_deregister_script( 'kadence-blocks-' . $this->block_name );
-			wp_enqueue_script( 'kadence-blocks-' . $this->block_name, KADENCE_BLOCKS_URL . 'includes/assets/js/kb-navigation-block.min.js', array('kadence-blocks-gumshoe'), KADENCE_BLOCKS_VERSION, true );
-		}
-
 		return sprintf(
 			'<div %1$s><nav %2$s><div class="menu-container"><ul %3$s>%4$s</ul></div></nav></div>',
 			$wrapper_attributes,
@@ -480,7 +450,7 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 	/**
 	 * Generates content to replace actual blocks for templated navigation placeholders.
 	 * This should match the templated blocks created in the editor for the same template keys
-	 *
+	 * 
 	 * @param array $attributes The database attribtues.
 	 */
 	public function applyTemplateKeyBlocks( $attributes ) {
@@ -519,7 +489,7 @@ class Kadence_Blocks_Navigation_Block extends Kadence_Blocks_Abstract_Block {
 						<!-- /wp:kadence/navigation -->
 					';
 					break;
-
+				
 				default:
 					return '
 						<!-- wp:kadence/navigation -->
