@@ -5,15 +5,17 @@
  * Description: OptinMonster is the best WordPress popup builder plugin that helps you grow your email newsletter list and sales with email popups, exit intent popups, floating bars and more!
  * Author:      OptinMonster Popup Builder Team
  * Author URI:  https://optinmonster.com
- * Version:     2.13.5
+ * Version:     2.16.8
  * Text Domain: optin-monster-api
  * Domain Path: languages
  *
  * WC requires at least: 3.2
- * WC tested up to:      7.7
+ * WC tested up to:      9.3
  * Requires at least:    4.7
  * Requires PHP:         5.3
- * Tested up to:         6.2
+ * Tested up to:         6.6
+ *
+ * @package OMAPI
  *
  * OptinMonster is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,6 +50,7 @@ define( 'OMAPI_FILE', __FILE__ );
  * @package OMAPI
  * @author  Thomas Griffin
  */
+#[\AllowDynamicProperties]
 class OMAPI {
 
 	/**
@@ -66,7 +69,7 @@ class OMAPI {
 	 *
 	 * @var string
 	 */
-	public $version = '2.13.5';
+	public $version = '2.16.8';
 
 	/**
 	 * The name of the plugin.
@@ -136,7 +139,6 @@ class OMAPI {
 		'notifications' => 'OMAPI_Notifications',
 		'classicEditor' => 'OMAPI_ClassicEditor',
 		// @since 2.10.0
-		'wordfence'     => 'OMAPI_Wordfence',
 		'urls'          => 'OMAPI_Urls',
 	);
 
@@ -150,6 +152,9 @@ class OMAPI {
 		// Load the plugin textdomain.
 		add_action( 'plugins_loaded', array( $this, 'load_plugin_textdomain' ) );
 
+		// Early action for WooCommerce compatibility.
+		add_action( 'before_woocommerce_init', 'OMAPI_WooCommerce::declare_hpos_compat' );
+
 		// Load the plugin widgets.
 		add_action( 'widgets_init', array( $this, 'widgets' ) );
 
@@ -177,6 +182,7 @@ class OMAPI {
 	 */
 	public function load_plugin_textdomain() {
 		$domain = 'optin-monster-api';
+		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound
 		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
 
 		load_textdomain( $domain, WP_LANG_DIR . '/' . $domain . '/' . $domain . '-' . $locale . '.mo' );
@@ -295,6 +301,13 @@ class OMAPI {
 			update_option( 'omapi_review', $review );
 		}
 
+		// Create a connection token if one doesn't exist, and we're not already connected.
+		$is_connected = ! empty( $option['api']['apikey'] ) && isset( $option['userId'] ) && 0 < absint( $option['userId'] );
+		if ( ! $is_connected && empty( $option['connectionToken'] ) ) {
+			$option['connectionToken'] = wp_hash( get_current_user_id() . site_url() . time() );
+			update_option( 'optin_monster_api', $option );
+		}
+
 		// Check/set the installation date.
 		if ( empty( $option['installed'] ) ) {
 
@@ -366,8 +379,8 @@ class OMAPI {
 		$this->welcome       = new OMAPI_Welcome();
 		$this->promos        = new OMAPI_Promos();
 		$this->notifications = new OMAPI_Notifications();
+		// phpcs:ignore WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
 		$this->classicEditor = new OMAPI_ClassicEditor();
-		$this->wordfence     = new OMAPI_Wordfence();
 
 		// Fire a hook to say that the admin classes are loaded.
 		do_action( 'optin_monster_api_admin_loaded' );
@@ -393,7 +406,7 @@ class OMAPI {
 	 * @since 1.0.0
 	 *
 	 * @param string $slug The optin slug used to retrieve a optin.
-	 * @return array|bool  Array of optin data or false if none found.
+	 * @return WP_Post|null  Array of optin data or false if none found.
 	 */
 	public function get_optin_by_slug( $slug ) {
 		$optin = get_page_by_path( sanitize_text_field( $slug ), OBJECT, OMAPI_Type::SLUG );
@@ -491,7 +504,7 @@ class OMAPI {
 	 *
 	 * @since 2.6.8
 	 *
-	 * @param WP_Post $post Optin post object.
+	 * @param WP_Post|null $post Optin post object.
 	 */
 	public function add_campaign_properties( $post ) {
 		$post = $this->validate_is_campaign_type( $post );
@@ -717,8 +730,12 @@ class OMAPI {
 	 * @param  mixed  $data Arbitrary data to be made available to the view file.
 	 *
 	 * @return void
+	 *
+	 * phpcs:disable Generic.CodeAnalysis.UnusedFunctionParameter.FoundAfterLastUsed
 	 */
 	public function output_view( $file, $data = array() ) {
+		// phpcs:enable Generic.CodeAnalysis.UnusedFunctionParameter.FoundAfterLastUsed
+
 		// Potentially use validate_file() (WP function) if we end up needing sub-directories later.
 		require dirname( $this->file ) . DIRECTORY_SEPARATOR . 'views' . DIRECTORY_SEPARATOR . basename( $file );
 	}
@@ -747,7 +764,7 @@ class OMAPI {
 	 * @param  string $file The view file.
 	 * @param  mixed  $data Arbitrary data to be made available to the view file.
 	 *
-	 * @return void
+	 * @return string
 	 */
 	public function get_min_css_view_contents( $file, $data = array() ) {
 		$contents = $this->get_view_contents( $file, $data );
@@ -765,7 +782,14 @@ class OMAPI {
 	 * @return void
 	 */
 	public function output_min_css( $file, $data = array() ) {
-		echo $this->get_min_css_view_contents( $file, $data );
+		echo wp_kses(
+			$this->get_min_css_view_contents( $file, $data ),
+			array(
+				'style' => array(
+					'type' => array(),
+				),
+			)
+		);
 	}
 
 	/**
@@ -846,6 +870,7 @@ class OMAPI {
 	public function has_rule_type( $rule_type ) {
 		$data = OMAPI_Api::fetch_me_cached();
 
+		// phpcs:ignore WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
 		return ! empty( $data->ruleTypes ) && in_array( $rule_type, (array) $data->ruleTypes, true );
 	}
 
@@ -941,16 +966,18 @@ class OMAPI {
 	 *
 	 * @since 2.10.0
 	 *
-	 * @param  strgin $page Page to check. Falls back to $_REQUEST['page'].
+	 * @param string $page Page to check. Falls back to $_REQUEST['page'].
 	 *
 	 * @return boolean Whether given (or current) page is an optinmonster admin page.
 	 */
 	public function is_om_page( $page = null ) {
+		// phpcs:disable WordPress.Security.NonceVerification.Recommended
 		if ( empty( $page ) && ! empty( $_REQUEST['page'] ) ) {
-			$page = $_REQUEST['page'];
+			$page = sanitize_key( wp_unslash( $_REQUEST['page'] ) );
 		}
+		// phpcs:enable WordPress.Security.NonceVerification.Recommended
 
-		return ! empty( $page ) && preg_match( '/optin-monster-/', sanitize_key( $page ) );
+		return ! empty( $page ) && preg_match( '/optin-monster-/', $page );
 	}
 
 	/**
@@ -999,6 +1026,11 @@ class OMAPI {
 		}
 	}
 
+	/**
+	 * Checks PHP version.
+	 *
+	 * @return void
+	 */
 	public function check_php_version() {
 
 		// Display for PHP below 5.6.
@@ -1112,7 +1144,7 @@ class OMAPI {
 		}
 
 		if ( ! empty( $timestamp ) ) {
-			$version = date( $format, (int) $timestamp );
+			$version = gmdate( $format, (int) $timestamp );
 		}
 
 		return $version;
@@ -1179,7 +1211,7 @@ class OMAPI {
 	 *
 	 * @since 2.11.2
 	 *
-	 * @param  string $property
+	 * @param string $property The property to retrieve.
 	 *
 	 * @return mixed
 	 */
@@ -1208,7 +1240,15 @@ function optin_monster_api_activation_hook( $network_wide ) {
 	global $wp_version;
 	if ( version_compare( $wp_version, '4.7.0', '<' ) && ! defined( 'OPTINMONSTER_FORCE_ACTIVATION' ) ) {
 		deactivate_plugins( plugin_basename( __FILE__ ) );
-		wp_die( wp_kses_post( sprintf( __( 'Sorry, but your version of WordPress does not meet OptinMonster\'s required version of <strong>4.7.0</strong> to run properly. The plugin has been deactivated. <a href="%s">Click here to return to the Dashboard</a>.', 'optin-monster-api' ), esc_url( admin_url() ) ) ) );
+		wp_die(
+			wp_kses_post(
+				sprintf(
+					/* translators: %s) admin url */
+					__( 'Sorry, but your version of WordPress does not meet OptinMonster\'s required version of <strong>4.7.0</strong> to run properly. The plugin has been deactivated. <a href="%s">Click here to return to the Dashboard</a>.', 'optin-monster-api' ),
+					esc_url( admin_url() )
+				)
+			)
+		);
 	}
 
 	$instance = OMAPI::get_instance();
@@ -1317,7 +1357,7 @@ if ( ! function_exists( 'optin_monster_tag' ) ) {
 	 *
 	 * @since 1.0.0
 	 *
-	 * @param int  $string The post name of the optin to load.
+	 * @param int  $id     The post name of the optin to load.
 	 * @param bool $return Flag to echo or return the optin HTML.
 	 */
 	function optin_monster_tag( $id, $return = false ) {
